@@ -646,7 +646,7 @@ class TestSSHHook:
             )
 
     @pytest.mark.parametrize(
-        "cmd_timeout, cmd_timeoutextra, null_cmd_timeoutextra, expected_value",
+        ("cmd_timeout", "cmd_timeoutextra", "null_cmd_timeoutextra", "expected_value"),
         [
             (TEST_CMD_TIMEOUT, True, False, TEST_CMD_TIMEOUT),
             (TEST_CMD_TIMEOUT, True, True, TEST_CMD_TIMEOUT),
