@@ -27,15 +27,17 @@ from paramiko.client import SSHClient
 
 from airflow.exceptions import AirflowException, AirflowSkipException, AirflowTaskTimeout
 from airflow.models import TaskInstance
-from airflow.models.serialized_dag import SerializedDagModel
+from airflow.providers.common.compat.sdk import timezone
 from airflow.providers.ssh.hooks.ssh import SSHHook
 from airflow.providers.ssh.operators.ssh import SSHOperator
-from airflow.utils.timezone import datetime
 from airflow.utils.types import NOTSET
 
 from tests_common.test_utils.config import conf_vars
+from tests_common.test_utils.dag import sync_dag_to_db
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
+datetime = timezone.datetime
+
 if AIRFLOW_V_3_0_PLUS:
     from airflow.models.dag_version import DagVersion
 
@@ -78,7 +80,7 @@ class TestSSHOperator:
             yield exec_ssh_client_command
 
     @pytest.mark.parametrize(
-        "cmd_timeout, cmd_timeout_expected",
+        ("cmd_timeout", "cmd_timeout_expected"),
         [(45, 45), ("Not Set", 10), (None, None)],
     )
     def test_hook_created_correctly(self, cmd_timeout, cmd_timeout_expected):
@@ -181,7 +183,7 @@ class TestSSHOperator:
             ).execute(None)
 
     @pytest.mark.parametrize(
-        "command, get_pty_in, get_pty_out",
+        ("command", "get_pty_in", "get_pty_out"),
         [
             (COMMAND, False, False),
             (COMMAND, True, True),
@@ -212,7 +214,7 @@ class TestSSHOperator:
         self.hook.get_conn.return_value.__exit__.assert_called_once()
 
     @pytest.mark.parametrize(
-        "extra_kwargs, actual_exit_code, expected_exc",
+        ("extra_kwargs", "actual_exit_code", "expected_exc"),
         [
             ({}, 0, None),
             ({}, 100, AirflowException),
@@ -272,8 +274,7 @@ class TestSSHOperator:
             task = SSHOperator(task_id="push_xcom", ssh_hook=self.hook, command=command)
         dr = dag_maker.create_dagrun(run_id="push_xcom")
         if AIRFLOW_V_3_0_PLUS:
-            dag.sync_to_db()
-            SerializedDagModel.write_dag(dag, bundle_name="testing")
+            sync_dag_to_db(dag)
             dag_version = DagVersion.get_latest_version(dag.dag_id)
             ti = TaskInstance(task=task, run_id=dr.run_id, dag_version_id=dag_version.id)
         else:
@@ -305,3 +306,13 @@ class TestSSHOperator:
             time.sleep(1)
 
             mock_on_kill.assert_called_once()
+
+    def test_remote_host_passed_at_hook_init(self):
+        remote_host = "test_host.internal"
+        task = SSHOperator(
+            task_id="test_remote_host_passed",
+            ssh_conn_id="ssh_default",
+            remote_host=remote_host,
+            command=COMMAND,
+        )
+        assert task.hook.remote_host == remote_host
